/*
 * Copyright 2026 Richard Hughes <richard@hughsie.com>
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#pragma once

#include <glib.h>

#define g_log_get_debug_enabled() (g_getenv("FWUPD_VERBOSE") != NULL)
